# Colton's Super Script

Here's an explanation of what my script does and how to use it. It's really super.

Lab members who create scripts should add documentation to the `/docs/user_scripts` in a new `your_super_script_name.md` file.
